clear all
close all
clc
%% Code for extracting the radiomics features, not in pyradiomics
% This is a research code and the user needs to modify the code as necessary
% Our code was developed using MATLAB version R2017a
 
%% Reference
% [1] Intratumor heterogeneity characterized by textural features on baseline 18 F-FDG PET images predicts response to concomitant radiochemotherapy in esophageal cancer (The Journal of nuclear medicine)
% [2] Pulmonary Ground-Glass Nodules: Increase in Mass as an Early Indicator of Growth (Radiology)
% [3] Solitary Pulmonary Nodular Lung Adenocarcinoma: Correlation of Histopathologic Scoring and Patient Survival with Imaging Biomarkers (Radiology)

%% Load image & ROI
% Read in NIFTI or hdr(img) file. 
% Next 2 lines require NIFIT toolbox ver 1.27
% Img part of ROI nifti file must be a binary matrix, which is 0 for background and 1 for tumor
image_nii = load_nii();
roi_nii = load_nii();

%% Histogram based feature (percentile histogram 2.5, 25, 50, 75, 97.5)
roi_idx = find(roi_nii.img);
inten_list = double(image_nii.img(roi_idx));
percentile_histogram = prctile(inten_list,[2.5 25 50 75 97.5]);

%% Shape feature (convexity)
unit_volume = roi_nii.hdr.dime.pixdim(2)*roi_nii.hdr.dime.pixdim(3)*roi_nii.hdr.dime.pixdim(4);
volume_SHAPE = unit_volume*length(find(roi_nii.img));
[roi_idx_i,roi_idx_j,roi_idx_k] = ind2sub(size(roi_nii.img),find(roi_nii.img));
[K,convex_volume] = convhull(roi_idx_i,roi_idx_j,roi_idx_k); 
convex_volume = convex_volume*unit_volume;
convexity_SHAPE = volume_SHAPE/convex_volume;

%% Intensity-size zone features (128 bins) [1]. This requires a separate function rad_ISZ (provided separately)
feature_ISZ = rad_ISZ(image_nii,roi_nii,128);

%% Save
features = [percentile_histogram, convexity_SHAPE, feature_ISZ];
xlswrite(strcat('radiomics_features.xlsx'), features, 1, 'A2');